# Segway
by Michael Hoffman `michael.hoffman at utoronto dot ca`

[![Join the chat at https://gitter.im/hoffman/segway](https://badges.gitter.im/Join%20Chat.png)](https://gitter.im/hoffman/segway?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Latest Version](https://img.shields.io/pypi/v/segway.png)](https://pypi.python.org/pypi/segway/)


# Description
The free Segway software package contains a novel method for analyzing multiple
tracks of functional genomics data. Our method uses a dynamic Bayesian network
(DBN) model, which enables it to analyze the entire genome at 1-bp resolution
even in the face of heterogeneous patterns of missing data. This method is the
first application of DBN techniques to genome-scale data and the first genomic
segmentation method designed for use with the maximum resolution data available
from ChIP-seq experiments without downsampling. Our software has extensive
documentation and was designed from the outset with external users in mind.
Researchers at other universities and institutes have already installed and
used Segway for their own projects.

Please see the following URL for information,
installation, and support: http://segway.hoffmanlab.org/

# Documentation
Live documentation based on this repository can be found on [Read the Docs](http://segway.readthedocs.io/en/latest/).


# Contributing
Contributions to Segway are always welcome and encouraged. See [CONTRIBUTING](CONTRIBUTING.md) for more information on how to get started.

# License
Segway is free software: you can redistribute it and/or modify it under the terms of version 2 of the GNU General Public License as published by the Free Software Foundation.

Segway is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.

# Contact
Please let us `segway-l at listserv dot utoronto dot ca` know if you have any comments on the installation or use of Segway, or [file an issue on Github](https://github.com/hoffmangroup/segway/issues).
